@@ -165,7 +165,7 @@ def select(
     """
     Runs a select query and returns results as dataframe
 
-    :param return_type: dataframe, json, dictionary or pyarrow; default is dataframe
+    :param return_type: dataframe, json, json string, dictionary or pyarrow; default is dataframe
     :param client: Client needed for API request
     :param sql: query sql
     :param timeout: job timeout parameter
@@ -182,6 +182,13 @@ def select(
     )
     if return_type == "json":
         return json.loads(result.to_dataframe().to_json(orient="records"))
+    elif return_type == "json_string":
+        return json.dumps(
+            result.to_dataframe().to_dict(orient="records"),
+            default=str,
+            indent=2,
+            ensure_ascii=False,
+        )
     elif return_type == "dict":
         return result.to_dataframe().to_dict(orient="records")
     elif return_type == "dataframe":
